@@ -199,11 +199,11 @@ class Sms(Event):
     }
 
 class Email(Event):
-    ARGS = ["user", "subject", "body"]
+    ARGS = ["user", "subject", "template"]
     PROPERTIES = {
         "+user": "user",
         "+subject": "string",
-        "+body": "html",
+        "+template": "media.hbs",
         "subscription": "string"
     }
 
@@ -309,37 +309,13 @@ class Kwargs(Script):
 # Variables
 # ------------------------
 class Varpath(Script):
-    def __init__(self, varpath, tags=[], offset=None, where=None, sortby=None, randunique=[], agg=None, time=None):
+    def __init__(self, varpath, tags=[]):
         self.varpath = '.'.join(varpath) if isinstance(varpath, list) else varpath
         self.tags = []
-        self.offset = offset
-        self.where = where
-        self.sortby = sortby
-        self.randunique = randunique
-        self.agg = agg
-        self.time = time
-
-        # need to define what this element is, or will be once produced
-        self.types = set(['twitter_handler'])
-
-        if where:
-            # need to check the where expressions: all varpaths exist in `varpaths`
-            pass
-
-        if sortby:
-            # need to check the `sortby[0]` exists in `varpath`
-            pass
 
     def json(self):
         dct = dict(path=self.varpath,
-                   tags=[t[2:] for t in set(self.tags)] if self.tags else None,
-                   offset=self.offset,
-                   where=self.where.json() if self.where else None,
-                   sortby=self.sortby,
-                   random=True if 'random' in self.randunique else None,
-                   unique=True if 'unique' in self.randunique else None,
-                   agg=self.agg,
-                   time=self.time)
+                   tags=[t[2:] for t in set(self.tags)] if self.tags else None)
         return dict([(name, value) for name, value in dct.items() if value is not None])
 
 class String(Script):
@@ -381,14 +357,14 @@ class String(Script):
             return dict(string=''.join(string).strip(), values=values)
 
         else:
-            return " ".join([d.strip() for d in self.datas]).strip()
+            return dict(value=" ".join([d.strip() for d in self.datas]).strip())
 
 class Number(Script):
     def __init__(self, number):
         self.number = number
 
     def json(self):
-        return self.number
+        return dict(value=self.number)
 
 # ------------------------
 # Expression
@@ -438,14 +414,59 @@ class Expression(Script):
         return dict(expression=" ".join([e for e in evals if e != ""]),
                     values=values)
 
+class AdvancedExpression(Script):
+    def __init__(self, expression, tags=[], offset=None, where=None, sortby=None, randunique=[], agg=None, time=None):
+        self.expression = expression
+        self.tags = []
+        self.offset = offset
+        self.where = where
+        self.sortby = sortby
+        self.randunique = randunique
+        self.agg = agg
+        self.time = time
+
+        # need to define what this element is, or will be once produced
+        self.types = set(['twitter_handler'])
+
+        if where:
+            # need to check the where expressions: all varpaths exist in `varpaths`
+            pass
+
+        if sortby:
+            # need to check the `sortby[0]` exists in `varpath`
+            pass
+
+    def json(self, scope="_"):
+        dct = self.expression.json()
+        if 'left' in dct:
+            dct['left'].update(dict(offset=self.offset if self.offset else None,
+                                    where=self.where.json() if self.where else None,
+                                    sortby=self.sortby,
+                                    random=True if 'random' in self.randunique else None,
+                                    unique=True if 'unique' in self.randunique else None,
+                                    agg=self.agg,
+                                    time=self.time.json() if self.time else None))
+            dct['left'] = dict([(name, value) for name, value in dct['left'].items() if value is not None])
+            return dct
+        else:
+            dct = self.expression.json()
+            dct.update(dict(offset=self.offset if self.offset else None,
+                            where=self.where.json() if self.where else None,
+                            sortby=self.sortby,
+                            random=True if 'random' in self.randunique else None,
+                            unique=True if 'unique' in self.randunique else None,
+                            agg=self.agg,
+                            time=self.time.json() if self.time else None))
+            return dict([(name, value) for name, value in dct.items() if value is not None])
+
 class Method(Script):
-    def __init__(self, varpath, method, other):
-        self.varpath = varpath
+    def __init__(self, left, method, right):
+        self.left = left
         self.method = method
-        self.other = other
+        self.right = right
 
     def json(self):
-        return dict(method=self.method, left=self.varpath.json(), right=self.other.json())
+        return dict(method=self.method, left=self.left.json(), right=self.right.json())
 
 class Regexp(Script):
     def __init__(self, regexp):
