@@ -307,10 +307,10 @@ class Parser(object):
             p[0] = []
 
     def p_varexp_offset(self, p):
-        '''offset : FIRST NUMBER
-                  | LAST NUMBER
-                  | NUMBER NUMBER
-                  | NUMBER
+        '''offset : FIRST DIGITS
+                  | LAST DIGITS
+                  | DIGITS DIGITS
+                  | DIGITS
                   | FIRST
                   | LAST
                   | '''    
@@ -334,6 +334,7 @@ class Parser(object):
     def p_varexp_agg(self, p):
         '''agg : AVERAGE
                | COUNT
+               | NUMBER OF
                | MAX
                | MIN
                | SMALLEST
@@ -345,6 +346,8 @@ class Parser(object):
                | '''
         if len(p) == 2:
             p[0] = p[1]
+        elif len(p) == 3:
+            p[0] = 'count'
 
     def p_varexp_time(self, p):
         '''time : FOR string
@@ -353,10 +356,10 @@ class Parser(object):
             p[0] = p[2]
 
     def p_varexp(self, p):
-        '''expression : agg offset randunique varpaths WHERE expressions SORTBY VARPATH ASCDESC time
-                      | agg offset randunique varpaths SORTBY VARPATH ASCDESC time
-                      | agg offset randunique varpaths WHERE expressions time
-                      | agg offset randunique varpaths time'''
+        '''expression : agg offset randunique expression WHERE expressions SORTBY varpaths ASCDESC time
+                      | agg offset randunique expression SORTBY varpaths ASCDESC time
+                      | agg offset randunique expression WHERE expressions time
+                      | agg offset randunique expression time'''
 
         if len(p) == 11:
             _ = dict(where=p[6], sortby=(p[8], p[9]), time=p[10])
@@ -367,11 +370,11 @@ class Parser(object):
         elif len(p) == 6:
             _ = dict(time=p[5])
 
-        p[0] = ast.Expression(ast.Varpath(varpath=p[4],
-                                          randunique=p[3],
-                                          offset=p[2],
-                                          agg=p[1],
-                                          **_))
+        p[0] = ast.AdvancedExpression(expression=p[4],
+                                      randunique=p[3],
+                                      offset=p[2],
+                                      agg=p[1],
+                                      **_)
 
     def p_stmt_set_varpath(self, p):
         '''stmt : SET VARPATH TO expressions NEWLINE'''
@@ -400,7 +403,7 @@ class Parser(object):
         p[0] = ast.Expression(expression=ast.Varpath(varpath=p[1]))
 
     def p_expression_num(self, p):
-        '''expression : NUMBER'''
+        '''expression : DIGITS'''
         p[0] = ast.Expression(expression=ast.Number(str(p[1])))
 
     def p_expression_var(self, p):
@@ -422,63 +425,72 @@ class Parser(object):
     def p_expression_has(self, p):
         '''expression : varpaths HAS VARPATH'''
         assert not p[3].endswith(']'), "Index lookup must not be a list"
-        p[0] = ast.Expression(expression=ast.Method(varpath=ast.Varpath(p[1]),
+        p[0] = ast.Expression(expression=ast.Method(left=ast.Varpath(p[1]),
                                                     method="has",
-                                                    other=ast.Varpath(p[3])))
+                                                    right=ast.Varpath(p[3])))
 
     def p_expression_in(self, p):
         '''expression : VARPATH IN varpaths'''
-        p[0] = ast.Expression(expression=ast.Method(varpath=ast.Varpath(varpath=p[1]),
+        p[0] = ast.Expression(expression=ast.Method(left=ast.Varpath(varpath=p[1]),
                                                     method="in",
-                                                    other=ast.Varpath(varpath=p[3])))
+                                                    right=ast.Varpath(varpath=p[3])))
 
     def p_expression_contains(self, p):
-        '''expression : varpaths CONTAINS VARPATH'''
-        p[0] = ast.Expression(expression=ast.Mehtod(varpath=ast.Varpath(varpath=p[1]),
+        '''expression : expression CONTAINS VARPATH'''
+        p[0] = ast.Expression(expression=ast.Method(varpath=p[1],
                                                     method="contains",
                                                     other=ast.Varpath(varpath=p[3])))
 
     def p_expression_likere(self, p):
-        '''expression : varpaths LIKE REGEX'''
-        p[0] = ast.Expression(expression=ast.Method(varpath=ast.Varpath(varpath=p[1]),
+        '''expression : expression LIKE REGEX'''
+        p[0] = ast.Expression(expression=ast.Method(left=p[1],
                                                     method="like",
-                                                    other=ast.Regexp(p[3])))
+                                                    right=ast.Regexp(p[3])))
 
     def p_expression_likestr(self, p):
-        '''expression : varpaths LIKE variable'''
-        p[0] = ast.Expression(expression=ast.Method(varpath=ast.Varpath(varpath=p[1]),
+        '''expression : expression LIKE variable'''
+        p[0] = ast.Expression(expression=ast.Method(left=p[1],
                                                     method="like",
-                                                    other=p[3]))
+                                                    right=p[3]))
 
     def p_expression_isnotequal(self, p):
-        '''expression : varpaths IS NOT EQUAL TO variable'''
-        p[0] = ast.Expression(expression=ast.Method(varpath=ast.Varpath(varpath=p[1]),
+        '''expression : expression IS NOT EQUAL TO variable'''
+        p[0] = ast.Expression(expression=ast.Method(left=p[1],
                                                     method="isnt",
-                                                    other=p[6]))
+                                                    right=p[6]))
 
     def p_expression_isequal(self, p):
-        '''expression : varpaths IS EQUAL TO variable'''
-        p[0] = ast.Expression(expression=ast.Method(varpath=ast.Varpath(varpath=p[1]),
+        '''expression : expression IS EQUAL TO variable'''
+        p[0] = ast.Expression(expression=ast.Method(left=p[1],
                                                     method="is",
-                                                    other=p[5]))
+                                                    right=p[5]))
+
+    def p_expression_isgtltthen(self, p):
+        '''expression : expression IS GREATER THEN expression
+                      | expression IS GREATER THAN expression
+                      | expression IS LESS THEN expression
+                      | expression IS LESS THAN expression'''
+        p[0] = ast.Expression(expression=ast.Method(left=p[1],
+                                                    method='<' if p[3] == 'less' else '>',
+                                                    right=p[5]))
 
     def p_expression_equals(self, p):
-        '''expression : varpaths EQUALS variable'''
-        p[0] = ast.Expression(expression=ast.Method(varpath=ast.Varpath(varpath=p[1]),
+        '''expression : expression EQUALS variable'''
+        p[0] = ast.Expression(expression=ast.Method(left=p[1],
                                                     method="is",
-                                                    other=p[3]))
+                                                    right=p[3]))
 
     def p_expression_is(self, p):
-        '''expression : varpaths IS expression'''
-        p[0] = ast.Expression(expression=ast.Method(varpath=ast.Varpath(varpath=p[1]),
+        '''expression : expression IS expression'''
+        p[0] = ast.Expression(expression=ast.Method(left=p[1],
                                                     method="is",
-                                                    other=p[3]))
+                                                    right=p[3]))
 
     def p_expression_isnt(self, p):
-        '''expression : varpaths ISNT expression'''
-        p[0] = ast.Expression(expression=ast.Method(varpath=ast.Varpath(varpath=p[1]),
+        '''expression : expression ISNT expression'''
+        p[0] = ast.Expression(expression=ast.Method(left=p[1],
                                                     method="isnt",
-                                                    other=p[3]))
+                                                    right=p[3]))
    
     # ------------------
     # Expressions > Math
