@@ -16,8 +16,7 @@ PLACEHOLDER_RESERVED_NAMES = [
     "layout",
     "modifier",
     "string",
-    "number"
-    ]
+    "number"]
 
 VARIABLE_RESERVED_NAMES = [
     "order",
@@ -57,6 +56,7 @@ KEYWORDS = [
   "average",
   "max",
   "min",
+  "number",
   
   # Helpers
   "for",
@@ -75,6 +75,11 @@ KEYWORDS = [
   "equals",
   "equal",
   "not",
+  "greater",
+  "less",
+  "then",
+  "than",
+  "of",
   
   # System
   "unset",
