@@ -24,7 +24,7 @@ class Timestring(Validator):
             raise ValidationError("Invalid date provided for %s" % (self.name, repr(element)))
 
 valideer.register("twitter_handler", ScriptElement("twitter_handler"))
-valideer.register("html", ScriptElement("html"))
+valideer.register("media.hbs", ScriptElement("media.hbs"))
 valideer.register("string", ScriptElement("string"))
 valideer.register("number", ScriptElement("number"))
 valideer.register("user", ScriptElement("user"))
